import { parseDicom, deteleFile, uploadFile2FastDfs, uploadFile2AliOss, getFileMD5, doUpload, charsetFormat } from '../../service/parseDicomService'
import { saveDicom } from '../../service/saveDicom'
import config from '../../../config'
// import fdfs from '../../service/fastdfs'
const options = config.upload || {}
const path = require('path');
/** 上传文件 */
export async function uploadFile(ctx) {
  const hospital = ctx.request.header.hospital;

  try {
    let results = await doUpload(ctx);
    for (let i = 0; i < results.length; i++) {
      results[i] = await doUploadSingle(results[i], hospital);
    }
    ctx.body = results;
  } catch (err) {
    console.log(err)
    ctx.body = { code: 1, err, msg: '上传出现错误' };
  }
}

async function doUploadSingle(result, hospital) {
  const filePath = path.join(options.path || '.', options.fileType || 'common', result.fileName);
  const md5 = await getFileMD5(filePath, result);
  // const fileId = await uploadFile2FastDfs(fdfs, filePath)
  const { url, metadata } = await uploadFile2AliOss(filePath, md5, hospital || result.hospital);
  const { dataSet, length } = await parseDicom(result)
  const saveFlag = await saveDicom(dataSet, length, url, metadata, hospital || result.hospital);
  const deleteFlag = await deteleFile(filePath)
  return {
    ...result,
    saveFlag,
    deleteFlag,
    url,
    metadata,
    // fileId,
    md5
  }
}
/** 上传文件页面检查 */
export async function showUpload(ctx) {
  const html = `
        <html lang="en">
            <head>
                <meta charset="UTF-8">
                <title>Title</title>
            </head>
            <body>
                <div>
                    <h1 style='font-size: 40px;'>请上传pacs图</h1>
                    <form method="POST" action="/upload" enctype="multipart/form-data">
                        <input name="filesize" type="input" style='width: 100%;height: 50px;font-size: 30px;margin-top: 30px;'/><br/><br/>
                        <input name="file" type="file" multiple="multiple" style='width: 100%;height: 50px;font-size: 40px';margin-top: 30px;/><br/><br/>
                        <button type="submit" style='width: 100%;height: 50px;font-size: 100px;'>提交</button>
                    </form>
                </div>
            </body>
        </html>
    `
  ctx.body = html
}
